@@ -2,8 +2,9 @@
 # Imports
 #
 from aes_cipher._version import __version__
-from aes_cipher.file_ex import FileEncodingError, FileHmacError
-from aes_cipher.file_data_encodings import FileDataEncodings
+from aes_cipher.data_ex import DataDecryptError, DataHmacError
+from aes_cipher.data_decrypter import DataDecrypter
+from aes_cipher.data_encrypter import DataEncrypter
 from aes_cipher.file_decrypter import FileDecrypter
 from aes_cipher.file_encrypter import FileEncrypter
 from aes_cipher.logger import Logger
