@@ -21,6 +21,7 @@
 #
 # Imports
 #
+from typing import List, Optional, Union
 from aes_cipher.data_decrypter import DataDecrypter
 from aes_cipher.file_reader import FileReader
 from aes_cipher.file_writer import FileWriter
@@ -34,20 +35,26 @@ from aes_cipher.logger import Logger
 # File decrypter class
 class FileDecrypter:
     # Constructor
-    def __init__(self, logger = Logger()):
+    def __init__(self,
+                 logger: Logger = Logger()) -> None:
         self.decrypter = DataDecrypter(logger)
 
     # Decrypt
-    def Decrypt(self, file_in, passwords, salt = None, itr_num = None):
+    def Decrypt(self,
+                file_in: str,
+                passwords: List[Union[str, bytes]],
+                salt: Optional[Union[str, bytes]] = None,
+                itr_num: Optional[int] = None) -> None:
         # Read file
         file_data = FileReader.Read(file_in)
         # Decrypt it
         self.decrypter.Decrypt(file_data, passwords, salt, itr_num)
 
     # Get decrypted data
-    def GetDecryptedData(self):
+    def GetDecryptedData(self) -> bytes:
         return self.decrypter.GetDecryptedData()
 
     # Save to file
-    def SaveTo(self, file_out):
+    def SaveTo(self,
+               file_out: str) -> None:
         FileWriter.Write(file_out, self.GetDecryptedData())
