@@ -21,8 +21,10 @@
 #
 # Imports
 #
+from typing import Union
 from Crypto.Hash import SHA512
 from Crypto.Protocol.KDF import PBKDF2
+from aes_cipher.utils import Utils
 
 
 #
@@ -33,5 +35,7 @@ from Crypto.Protocol.KDF import PBKDF2
 class Pbkdf2Sha512:
     # Compute
     @staticmethod
-    def Compute(password, salt, itr_num):
-        return PBKDF2(password, salt, SHA512.digest_size, itr_num, hmac_hash_module=SHA512)
+    def Compute(password: Union[str, bytes],
+                salt: Union[str, bytes],
+                itr_num: int) -> bytes:
+        return PBKDF2(Utils.Encode(password), Utils.Encode(salt), SHA512.digest_size, itr_num, hmac_hash_module=SHA512)
